@@ -2,7 +2,7 @@
                           dcapplicationevents.h  -  description
                              -------------------
     begin                : Don Aug 21 2003
-    copyright            : (C) 2003 by Mathias Kster
+    copyright            : (C) 2003 by Mathias Küster
     email                : mathen@users.berlios.de
  ***************************************************************************/
 
@@ -18,13 +18,14 @@
 #ifndef DCAPPLICATIONEVENTS_H
 #define DCAPPLICATIONEVENTS_H
 
-#include <qwidget.h>
+#include <qobject.h>
+#include <qevent.h>
 
 /**
-  *@author Mathias Kster
+  *@author Mathias Küster
   */
 
-class DCApplicationEvents : public QWidget
+class DCApplicationEvents : public QObject
 {
 Q_OBJECT
 
