@@ -2,7 +2,7 @@
                           dcconfig.h  -  description
                              -------------------
     begin                : Fri Mar 1 2002
-    copyright            : (C) 2002 by Mathias Kster
+    copyright            : (C) 2002 by Mathias Küster
     email                : mathen@users.berlios.de
  ***************************************************************************/
 
@@ -19,55 +19,44 @@
 #define DCCONFIG_H
 
 /**
-  *@author Mathias Kster
+  *@author Mathias Küster
   */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
-#include <qpixmap.h>
-#include <qvaluevector.h>
-#include <qlistview.h>
-#include <qheader.h>
-#include <qptrlist.h>
 #include <qimage.h>
 #include <qobject.h>
+#include <QByteArray>
+#include <QMap>
+#include <QList>
+#include <QStringList>
+
+// the typedef in dcfriendobject.h prevents the forward
+// declaration of "class FriendMap;" from working
+#include "dcfriendobject.h"
 
 #include <dclib/cconfig.h>
 
-#include <libxml/xmlversion.h>
-#if LIBXML_VERSION > 20406
-#include <libxml/globals.h>
-#endif
-#include <libxml/parser.h>
-#include <libxml/tree.h>
+#define USERLIST_XPM_COLUMNS      9
+#define USERLIST_XPM_ROWS        32
+#define USERLIST_ICON_SIZE       16
 
 /** */
-typedef enum eUserIconType {
-	euitOPERATOR,
-	euitUSER,
-	euitUSER_AWAY
-} eUserIconType;
-
-/** */
-typedef enum eUserSound {
+enum eUserSound {
 	eusCONNECT,
 	eusDISCONNECT,
 	eusSEND,
 	eusRECEIVE,
 	eusFIRSTRECEIVE,
 	eusNICKMENTIONED
-} eUserSound;
+};
 
 /** */
-typedef enum eTimeStamp {
+enum eTimeStamp {
 	etsPRIVATECHAT,
 	etsHUBCHAT
-} eTimeStamp;
+};
 
 /** */
-typedef enum eTransferViewOptions {
+enum eTransferViewOptions {
 	etvoCHUNKPERCENT,
 	etvoFILEPERCENT,
 	etvoCHUNKSIZE,
@@ -76,10 +65,10 @@ typedef enum eTransferViewOptions {
 	etvoELAPSEDTIMESINGLE,
 	etvoDOWNLOADRATEMULTI,
 	etvoELAPSEDTIMEMULTI
-} eTransferViewOptions;
+};
 
 /** */
-typedef enum eLogChatOptions {
+enum eLogChatOptions {
 	elcoENABLELOGGING,
 	elcoAPPENDDATE,
 	elcoAPPENDHUBNAME,
@@ -87,10 +76,10 @@ typedef enum eLogChatOptions {
 	elcoDISABLEPUBLICCHAT,
 	elcoENABLENICKNAMEFILTER,
 	elcoNICKNAMEFILTER_ENABLELOGGING
-} eLogChatOptions;
+};
 
 /** */
-typedef enum eChatColor {
+enum eChatColor {
 	eccCHATTIMESTAMP=0,
 	eccCHATLOCALNICK,
 	eccCHATLOCALTEXT,
@@ -110,43 +99,46 @@ typedef enum eChatColor {
 	eccCHATSAY,
 	eccPUBLICCHATMENICK,
 	eccOPNICK
-} eChatColor;
+};
 
-typedef enum eClientColumn {
-	eclcCOMMENT=0,
-	eclcTAG,
-	eclcEMAIL,
-	eclcSPEED,
-	eclcSHARE,
-	eclcIP,
-	eclcLOCKPK,
-	eclcSUPPORTS,
-	eclcNICK
-} eClientColumn;
+/* Download not supported */
+enum eMagnetAction {
+	eMagnetPrompt=0,
+	eMagnetSearch,
+	eMagnetDownload,
+	eMagnetNothing
+};
 
-class CString;
-class CThread;
+/* External magnet links not handled */
+enum eMagnetSource {
+	eChatMagnet=0,
+	eExternalMagnet
+};
 
 /* Default application font. Needed from main.cpp too */
 #define DEFAULT_APP_FONT	"Helvetica,12,-1,5,50,0,0,0,0,0"
 
-class QProcess;
 class QPixmap;
+class QProcess;
+class QTextDocument;
+class CXml;
+class CMessageMyInfo;
+
 /** */
 typedef QMap<QString, QString> StringMap;
 /** */
 typedef QMap<QString, StringMap*> SettingMap;
 
 /** */
-class DC_EmoticonObject : public CObject {
+class DC_EmoticonObject {
 public:
 	/** construtor */
 	DC_EmoticonObject() {};
 	/** destructor */
-	virtual ~DC_EmoticonObject() {};
+	~DC_EmoticonObject() {};
 
 	/** */
-	CString m_Text;
+	QString m_Text;
 	/** */
 	int left,top,right,bottom;
 	/** */
@@ -154,24 +146,24 @@ public:
 };
 
 /** */
-class DC_HubFilterObject : public CObject {
+class DC_HubFilterObject {
 public:
 	/** construtor */
 	DC_HubFilterObject() {
 		m_nUser        = 0;
-		m_bName        = FALSE;
-		m_bServer      = FALSE;
-		m_bDescription = FALSE;
+		m_bName        = false;
+		m_bServer      = false;
+		m_bDescription = false;
 	};
 	/** destructor */
-	virtual ~DC_HubFilterObject() {};
+	~DC_HubFilterObject() {};
 
 	/** */
-	CString m_sFilterName;
+	QString m_sFilterName;
 	/** */
-	CString m_sContains;
+	QString m_sContains;
 	/** */
-	int m_nUser;
+	unsigned int m_nUser;
 	/** */
 	bool m_bName;
 	/** */
@@ -181,64 +173,67 @@ public:
 };
 
 /** Stores a user command for custom menus */
-class DLL_EXPORT DC_UserMenuCommand : public CObject {
+class DC_UserMenuCommand {
 public:
 	/** */
 	DC_UserMenuCommand() {
-		m_nID      = 0;
-		m_nContext = 0;
-		
+		m_nContext  = 0;
+		m_nType     = -1;
 	};
 	/** */
-	virtual ~DC_UserMenuCommand() {};
+	~DC_UserMenuCommand() {};
+	/**
+	 * Command type. Separator, Raw or RawOnce.
+	 */
+	int m_nType;
 	/** The name of the menu command */
-	CString m_sName;
+	QString m_sName;
 	/** The command to send to the hub */
-	CString m_sCommand;
-	/** Menu id */
-	int m_nID;
+	QString m_sCommand;
 	/** Context is which menu(s) to put the command into */
 	int m_nContext;
+	/** Hub IP / DNS */
+	QString m_sHubIP;
 };
 
 /** Stores a user custom chat command */
-class DLL_EXPORT DC_UserChatCommand : public CObject {
+class DC_UserChatCommand {
 public:
 	/** */
 	DC_UserChatCommand() {};
 	/** */
-	virtual ~DC_UserChatCommand() {};
+	~DC_UserChatCommand() {};
 	
 	/** Name of the command */
-	CString m_sName;
+	QString m_sName;
 	/** Command string to run */
-	CString m_sCommand;
+	QString m_sCommand;
 };
 
 /** Stores an auto response trigger and response pair */
-class DC_AutoResponseObject : public CObject {
+class DC_AutoResponseObject {
 public:
 	/** */
 	DC_AutoResponseObject() {
-		m_sTrigger = "";
-		m_sResponse = "";
-		m_bCaseSensitive = FALSE;
+		m_bCaseSensitive = false;
 	};
 	/** */
-	virtual ~DC_AutoResponseObject() {};
+	~DC_AutoResponseObject() {};
 	
 	/** Trigger QT regexp */
-	CString m_sTrigger;
+	QString m_sTrigger;
 	/** Response */
-	CString m_sResponse;
+	QString m_sResponse;
 	/** Case sensitive or not */
 	bool m_bCaseSensitive;
 };
 
-class DCConfig : public CConfig {
+class DCConfig : public QObject, public CConfig {
+Q_OBJECT
+
 public:
 	/** construtor */
-	DCConfig( CString configpath = "" );
+	DCConfig( CString configpath = CString() );
 	/** destructor */
 	virtual ~DCConfig();
 
@@ -252,17 +247,17 @@ public:
 	/** */
 	int SaveDCGui();
 	/** */
-	void ParseDCGuiConfig( xmlNodePtr node );
+	void ParseDCGuiConfig( CXml * xml );
 
 	/** */
-	int LoadDCHubFilter( CStringList * list );
+	int LoadDCHubFilter( QMap<QString, DC_HubFilterObject*> * map );
 	/** */
-	int SaveDCHubFilter( CStringList * list );
+	int SaveDCHubFilter( QMap<QString, DC_HubFilterObject*> * map );
 
 	/** */
-	int LoadDCFriendList( CStringList * list );
+	int LoadDCFriendList( FriendMap * map );
 	/** */
-	int SaveDCFriendList( CStringList * list );
+	int SaveDCFriendList( FriendMap * map );
 
 	/** */
 	bool GetOpenPrivateChatWindow() const;
@@ -290,17 +285,22 @@ public:
 	/** */
 	void SetTransferViewOptions( eTransferViewOptions e, bool b );
 	/** */
-	CString GetTheme() const;
+	QString GetTheme() const;
 	/** */
-	void SetTheme( CString theme );
+	void SetTheme( QString theme );
+	/**
+	 * 0 is Ctrl + Enter
+	 * 1 is Enter
+	 * 2 is Alt + Enter
+	 * 3 is Alt + S
+	 */
+	int GetSendChat() const;
 	/** */
-	CString GetSendChat() const;
+	void SetSendChat( int index );
 	/** */
-	void SetSendChat( CString sendchat );
+	QString GetLanguageFile() const;
 	/** */
-	CString GetLanguageFile() const;
-	/** */
-	void SetLanguageFile( CString languagefile );
+	void SetLanguageFile( QString languagefile );
 	/** */
 	bool GetTabBar() const;
 	/** */
@@ -319,37 +319,28 @@ public:
 	void SetUserListRightAlignment( bool b );
 
 	/** */
-	QPixmap * GetUserIcon( bool op, eClientMode clientmode, eUserAwayMode awaymode, eUserSpeed speed, eUserClientVersion version );
+	QPixmap * GetUserIcon( CMessageMyInfo * myinfo );
 	/** */
 	void PlaySound( eUserSound usersound );
 	/** */
-	void PlaySound( CString file );
+	void PlaySound( QString file );
 
 	/** */
-	void SetAppFont( CString font );
+	void SetAppFont( QString font );
 	/** */
-	CString GetAppFont() const;
+	QString GetAppFont() const;
+	/** Set enable use of AppFont or use default font */
+	void SetUseCustomFont( bool b );
+	/** Get enable use of AppFont or use default font */
+	bool GetUseCustomFont() const;
 
 	/** */
-	bool GetMap( CString name, StringMap *& map );
-
-	/** */
-	void SetGeometry( CString name, int x, int y, int width, int height );
-	/** */
-	void GetGeometry( CString name, int &x, int &y, int &width, int &height );
+	bool GetMap( QString name, StringMap *& map );
 
 	/** */
 	void SetAppGeometry( int width, int height );
 	/** */
 	void GetAppGeometry( int &width, int &height );
-	/** */
-	void SetTransferViewGeometry( int width, int height );
-	/** */
-	void GetTransferViewGeometry( int &width, int &height );
-	/** */
-	void SetTransferViewDocked( bool b );
-	/** */
-	bool GetTransferViewDocked() const;
 
 	/** */
 	bool GetSoundDisabled() const;
@@ -364,13 +355,13 @@ public:
 	/** */
 	void SetExternalSoundPlayer( bool externalsoundplayer );
 	/** */
-	CString GetExternalPlayer() const;
+	QString GetExternalPlayer() const;
 	/** */
-	void SetExternalPlayer( CString externalplayer );
+	void SetExternalPlayer( QString externalplayer );
 	/** */
-	CString GetSoundFile( eUserSound usersound );
+	QString GetSoundFile( eUserSound usersound );
 	/** */
-	void SetSoundFile( eUserSound usersound, CString soundfile );
+	void SetSoundFile( eUserSound usersound, QString soundfile );
 	/** */
 	bool GetSoundEnabled( eUserSound usersound );
 	/** */
@@ -386,11 +377,11 @@ public:
 	/** */
 	bool GetLogChatOption( eLogChatOptions elco );
 	/** */
-	void SetLogChatNickNameFilter( CList<CString> * list );
+	void SetLogChatNickNameFilter( QStringList list );
 	/** */
-	void GetLogChatNickNameFilter( CList<CString> * list );
+	QStringList GetLogChatNickNameFilter();
 	/** */
-	bool CheckLogChatNickNameFilter( CString nick );
+	bool CheckLogChatNickNameFilter( QString nick );
 
 	/** */
 	bool GetShowStatusMessage() const;
@@ -416,9 +407,11 @@ public:
 	/** */
 	void SetAutoAwayMode( bool b );
 	/** */
-	int GetAutoAwayTime() const;
+	unsigned int GetAutoAwayTime() const;
 	/** */
-	void SetAutoAwayTime( int n );
+	void SetAutoAwayTime( unsigned int n );
+	/** */
+	virtual void SetAwayMode( eUserAwayMode mode );
 
 	/** */
 	int GetChatMessageMaxLines() const;
@@ -439,18 +432,24 @@ public:
 	/** */
 	void SetThemeSupport( bool b );
 	/** */
-	CString GetBackgroundPixmap() const;
+	QString GetBackgroundPixmap() const;
 	/** */
-	void SetBackgroundPixmap( CString s );
+	void SetBackgroundPixmap( QString s );
 	/** */
-	CString GetBrowser() const;
+	QString GetBrowser() const;
 	/** */
-	void SetBrowser( CString s );
+	void SetBrowser( QString s );
+	/** Open the URL using the browser settings */
+	void OpenURL( QString url );
+	/** */
+	bool GetCustomBrowser() const;
+	/** */
+	void SetCustomBrowser( bool b );
 
 	/** */
 	unsigned int GetDefaultDownloadMode() const;
 	/** 0:ask, 1:single, 2:multi */
-	void SetDefaultDownloadMode( unsigned int n );
+	void SetDefaultDownloadMode( unsigned int n, bool emitsig = false );
 
 	/** */
 	bool GetEnableTray() const;
@@ -474,57 +473,59 @@ public:
 	/** */
 	void SetShowChatInTab( bool b );
 	/** */
-	CString GetChatColor( eChatColor type ) const;
+	QString GetChatColor( eChatColor type ) const;
 	/** */
-	void SetChatColor( eChatColor type, CString s );
+	void SetChatColor( eChatColor type, QString s );
+ 	/** */
+	QString GetChatBackgroundColor() const;
 	/** */
-	bool GetOpenClientWindowsMinimized() const;
+	bool GetChatBackgroundColorEnabled() const;
 	/** */
-	void SetOpenClientWindowsMinimized( bool b );
-
+	void SetChatBackgroundColor( bool enabled, QString color );
+	/**
+	 * 0 = minimized
+	 * 1 = normal
+	 * 2 = maximized
+	 */
+	int GetOpenClientWindows() const;
 	/** */
-	bool GetClientColumn( eClientColumn e );
-	/** */
-	void SetClientColumn( eClientColumn e, bool b );
-
-	/** */
-	int GetClientColumnWidth( eClientColumn e );
-	/** */
-	void SetClientColumnWidth( eClientColumn e, int i );
+	void SetOpenClientWindows( int i );
 
 	/** */
 	bool InitMimeSourceFactory();
 	/** */
-	CList<DC_EmoticonObject> * EmoticonList();
+	QList<DC_EmoticonObject*> * EmoticonList();
 	/** */
 	QImage & GetEmoticonImage();
+	/** adds emoticon resources to the text document */
+	bool AddEmoticons( QTextDocument * document );
 
 	/** */
-	CString GetUserPhotoFileName() const;
+	QString GetUserPhotoFileName() const;
 	/** */
-	void SetUserPhotoFileName( CString s );
-	
-	/** Get the defualt remote text encoding for filelist browsers */
-	QString GetDefaultFBRemoteEncoding() const;
-	/** Set the default remote text encoding for filelist browsers */
-	void SetDefaultFBRemoteEncoding ( QString s );
+	void SetUserPhotoFileName( QString s );
 	
 	/** */
 	QString GetValknutDataPath() const;
 	/** */
 	void SetValknutDataPath( QString s );
 	
-	/** Get the list of user chat commands */
-	long GetUserChatCommands( CList<DC_UserChatCommand> * list );
-	/** Set the list of user chat commands */
-	void SetUserChatCommands( CList<DC_UserChatCommand> * list );
+	/** Get the list of user chat commands, caller must delete them */
+	long GetUserChatCommands( QList<DC_UserChatCommand*> * list );
+	/** Set the list of user chat commands, transfers ownership of the objects to g_pConfig */
+	void SetUserChatCommands( QList<DC_UserChatCommand*> * list );
+	/**
+	 * Instead of copying the list of commands to a DCChat and then deleting them all,
+	 * send the text to g_pConfig and get the text with the commands substituted.
+	 */
+	QString ReplaceUserChatCommands( QString text );
 	
-	/** Get the list of user menu commands */
-	long GetUserMenuCommands( CList<DC_UserMenuCommand> * list );
-	/** Set the list of user menu commands*/
-	void SetUserMenuCommands( CList<DC_UserMenuCommand> * list );
-	/** Loads the user icons */
-	void SetUserIcons( QPixmap p );	
+	/** Get a copy of the list of user menu commands, caller must delete them */
+	long GetUserMenuCommands( QMap<int, DC_UserMenuCommand*> * list );
+	/** Get pointers to the actual user menu commands */
+	long GetUserMenuCommandsDirect( QMap<int, DC_UserMenuCommand*> * list );
+	/** Set the list of user menu commands, transfers ownership of the objects to g_pConfig */
+	void SetUserMenuCommands( QMap<int, DC_UserMenuCommand*> * list );
 	
 	/** Gets the theme for application icons */
 	QString GetApplicationIconTheme() const;
@@ -538,7 +539,11 @@ public:
 	
 	/** Gets the theme for userlist icons */
 	QString GetUserListIconTheme() const;
-	/** Sets the theme for userlist icons */
+	/**
+	 * Sets the theme for userlist icons.
+	 * Clears all cached pixmaps and loads the new image
+	 * if the theme has changed.
+	 */
 	void SetUserListIconTheme( QString s );
 	
 	/** Gets the regexp of nicks to not open chat windows for */
@@ -546,40 +551,59 @@ public:
 	/** Sets the regexp of nicks to not open chat windows for */
 	void SetSuppressedNicks( QString s );
 	
-	/** Gets the action for double clicking a user */
-	QString GetDoubleClickAction() const;
+	/**
+	 * Gets the action for double clicking a user
+	 * 0 is private chat
+	 * 1 is download filelist
+	 */
+	int GetDoubleClickAction() const;
 	/** Sets the action for double clicking a user */
-	void SetDoubleClickAction( QString s );
+	void SetDoubleClickAction( int index );
 	
 	/** Gets if auto responder is enabled for main chat */
 	bool GetAutoResponderEnabled() const;
 	/** Enables/Disables the auto responder for main chat */
 	void SetAutoResponderEnabled( bool b );
-	/** Gets the list of auto response triggers and responses */
-	long GetAutoResponses( CList<DC_AutoResponseObject> * list );
-	/** Sets the list of auto response triggers and responses */
-	void SetAutoResponses( CList<DC_AutoResponseObject> * list );
+	/** Gets the list of auto response triggers and responses, the caller must delete them */
+	long GetAutoResponses( QList<DC_AutoResponseObject*> * list );
+	/** Sets the list of auto response triggers and responses, transfers ownership of the objects to g_pConfig */
+	void SetAutoResponses( QList<DC_AutoResponseObject*> * list );
 	/** Gets the minimum time between auto-responses */
 	long GetAutoResponseDelay() const;
 	/** Sets the minimum time between auto-responses */
 	void SetAutoResponseDelay( long n );
 	/** Gets list of nicks to not auto respond to */
-	CString GetAutoResponseIgnores() const;
+	QString GetAutoResponseIgnores() const;
 	/** Sets list of nicks to not auto respond to */
-	void SetAutoResponseIgnores( CString s );
+	void SetAutoResponseIgnores( QString s );
 	/** Gets if the auto responder is enabled for PMs */
 	bool GetAutoResponderEnabledForPM() const;
 	/** Enables/Disabled the auto responder for private messages */
 	void SetAutoResponderEnabledForPM( bool b );
 	
-	/** Gets filelist naming scheme version */
+	/** Gets filelist naming scheme version
+	  * This is set internally so that the filelists are renamed
+	  * once only when upgrading to 0.3.10.
+	  * once only when upgrading to 0.3.17.
+	  *
+	  * 0 = 0.3.8 or earlier integers
+	  * 1 = 0.3.9 base64 encoded
+	  * 2 = 0.3.10 human readable nick-hubhost_port.filelist
+	  * 3 = setting was abused for searchindex changes
+	  * 4 = 0.3.17 human readable nick@hubhost_port.filelist
+	  */
 	int GetFilelistNamingSchemeVersion() const;
 	/** Sets filelist naming scheme version */
 	void SetFilelistNamingSchemeVersion( int i );
 	/** Renames the filelists */
 	void RenameStoredFilelists();
 	
-	/** Get show folders in right pane of filelist browser*/
+	/** Gets QMainWindow saved state */
+	QByteArray GetQMainWindowState() const;
+	/** Sets QMainWindow state */
+	void SetQMainWindowState( QByteArray b );
+	
+	/** Get show folders in right pane of filelist browser */
 	bool GetFoldersInRightPane() const;
 	/** Set show folders in right pane of filelist browser */
 	void SetFoldersInRightPane( bool b );
@@ -591,6 +615,76 @@ public:
 	bool GetFoldersInRightPaneOnTop() const;
 	/** Set sort folders in right pane on top */
 	void SetFoldersInRightPaneOnTop( bool b );
+	/** Get double click right pane folders opens them */
+	bool GetOpenFoldersInRightPane() const;
+	/** Set double click right pane folders opens them */
+	void SetOpenFoldersInRightPane( bool b );
+	/** Get send unknown /commands as chat */
+	bool GetSendUnknownCommandsAsChat() const;
+	/** Set send unknown /commands as chat */
+	void SetSendUnknownCommandsAsChat( bool b );
+	/** Get allowed unknown commands */
+	QString GetAllowedUnknownCommands() const;
+	/** Set allowed unknown commands */
+	void SetAllowedUnknownCommands( QString s );
+	/** Get fix hub details in search results */
+	bool GetAdjustSearchResultHubNames() const;
+	/** Set fix hub details in search results */
+	void SetAdjustSearchResultHubNames( bool b );
+	/** Get remove public hub menu item enabled */
+	bool GetRemovePublicHubEnabled() const;
+	/** Set remove public hub menu item enabled */
+	void SetRemovePublicHubEnabled( bool b );
+	
+	/** Tab completion mode
+	 * 0 = contains
+	 * 1 = startsWith
+	 */
+	int GetTabCompleteMatchMode() const;
+	/** And set tab completion mode */
+	void SetTabCompleteMatchMode( int i );
+	/** Remove [] tags from nicks */
+	bool GetTabCompleteStripTags() const;
+	/** Set remove [] tags from nicks */
+	void SetTabCompleteStripTags( bool b );
+	
+	/** Get use threads for running shell commands from chat */
+	bool GetThreadsForShellCommands() const;
+	/** Set use threads for running shell commands from chat */
+	void SetThreadsForShellCommands( bool b );
+	/** Get shell command timeout (seconds) */
+	int GetShellCommandTimeout() const;
+	/** Set shell command timeout (seconds) */
+	void SetShellCommandTimeout( int s );
+	
+	/** Get use submenu for user commands */
+	bool GetUserCommandSubmenu() const;
+	/** Set use submenu for user commands */
+	void SetUserCommandSubmenu( bool b );
+	
+	/** Get default magnet action */
+	eMagnetAction GetMagnetAction( eMagnetSource = eChatMagnet ) const;
+	/** Set default magnet action */
+	void SetMagnetAction( eMagnetAction act, eMagnetSource = eChatMagnet );
+	
+	/** Get alternating row colors */
+	bool GetAlternatingRowColors() const;
+	/** Set alternating row colors */
+	void SetAlternatingRowColors( bool b );
+	
+signals:
+	/** emitted when the emoticon theme has changed */
+	virtual void emoticonThemeChanged();
+	/** emitted after chat background color settings have changed */
+	virtual void chatBackgroundColorChanged();
+	/** emitted after the default download mode has been changed not from the main menu */
+	virtual void defaultDownloadModeChanged();
+	/** emitted when the away mode is changed */
+	virtual void awayModeChanged( eUserAwayMode newmode );
+	/** emitted when the alternating rows colors setting changes, parameter is new setting */
+	virtual void alternatingRowColorsChanged( bool enabled );
+	/** emitted when auto away mode is enabled or disabled */
+	virtual void autoAwayModeChanged( bool enabled );
 	
 private:
 	/** */
@@ -616,25 +710,23 @@ private:
 	/** */
 	eUnit m_eUnit;
 	/** */
-	CString sTheme;
+	QString sTheme;
+	/** Needed to avoid removing the QT3 version's theme setting */
+	QString sThemeQT3;
 	/** */
-	CString sSendChat;
+	int m_nSendChat;
 	/** */
 	bool bThemeSupport;
 	/** */
-	CString sLanguageFile;
+	QString sLanguageFile;
 	/** Application font */
-	CString sAppFont;
+	QString sAppFont;
+	/** If true, use sAppFont, if false, use system default font */
+	bool m_bUseCustomFont;
 	/** Application height */
 	int iAppHeight;
 	/** Application Width */
 	int iAppWidth;
-	/** TransferView height */
-	int iTransferViewHeight;
-	/** TransferView Width */
-	int iTransferViewWidth;
-	/** TransferView Docked */
-	int bTransferViewDocked;
 	/** */
 	bool bSoundDisabled;
 	/** */
@@ -654,19 +746,19 @@ private:
 	/** */
 	bool bExternalSoundPlayer;
 	/** */
-	CString sExternalPlayer;
+	QString sExternalPlayer;
 	/** connect sound file */
-	CString sSoundFileConnect;
+	QString sSoundFileConnect;
 	/** disconnect sound file */
-	CString sSoundFileDisconnect;
+	QString sSoundFileDisconnect;
 	/** send sound file */
-	CString sSoundFileSend;
+	QString sSoundFileSend;
 	/** receive sound file */
-	CString sSoundFileReceive;
+	QString sSoundFileReceive;
 	/** first receive sound file */
-	CString sSoundFileFirstReceive;
+	QString sSoundFileFirstReceive;
 	/** nick said in public chat */
-	CString sSoundFileNickMentioned;
+	QString sSoundFileNickMentioned;
 
 	/** */
 	bool bEnableEmoticons;
@@ -710,12 +802,10 @@ private:
 	/** */
 	bool m_bLogChatOption_7;
 	/** */
-	CList<CString> m_pLogChatNickNameFilter;
+	QStringList m_LogChatNickNameFilter;
 
 	/** */
 	int iChatMessageMaxLines;
-	/** */
-	QMimeSourceFactory * m_pMimeSourceFactory;
 	
 	/** */
 	int iFloodCount;
@@ -723,7 +813,7 @@ private:
 	bool m_bFloodOpKick;
 
 	/** */
-	CList<DC_EmoticonObject> * m_EmoticonSettingList;
+	QList<DC_EmoticonObject*> * m_pEmoticons;
 	/** */
 	QImage m_EmoticonImage;
 
@@ -731,18 +821,16 @@ private:
 	QProcess * pProcess;
 
 	/** */
-	QPixmap m_UserIconCache;
-	/** */
-	int m_nUICX,m_nUICY;
+	QPixmap * m_UserIconCache[USERLIST_XPM_COLUMNS][USERLIST_XPM_ROWS];
 	/** */
 	QImage m_UserIcons;
 
 	/** 0:ask, 1:single, 2:multi */
-	int iDefaultDownloadMode;
+	unsigned int iDefaultDownloadMode;
 	/** */
 	bool m_bAutoAwayMode;
 	/** */
-	int m_nAutoAwayTime;
+	unsigned int m_nAutoAwayTime;
 
 	/** */
 	bool m_bEnableTray;
@@ -753,103 +841,70 @@ private:
 	/** */
 	bool bShowChatSendButton;
 	/** */
-	CString sBackgroundPixmap;
+	QString sBackgroundPixmap;
 	/** */
-	CString sBrowser;
+	QString sBrowser;
+	/** true to use sBrowser, false to use QDesktopServices */
+	bool m_bCustomBrowser;
 	/** */
 	bool bShowChatInTab;
 	/** */
-	CString m_sChatColor_1;
+	QString m_sChatColor_1;
 	/** */
-	CString m_sChatColor_2;
+	QString m_sChatColor_2;
 	/** */
-	CString m_sChatColor_3;
+	QString m_sChatColor_3;
 	/** */
-	CString m_sChatColor_4;
+	QString m_sChatColor_4;
 	/** */
-	CString m_sChatColor_5;
+	QString m_sChatColor_5;
 	/** */
-	CString m_sChatColor_6;
+	QString m_sChatColor_6;
 	/** */
-	CString m_sChatColor_7;
+	QString m_sChatColor_7;
 	/** */
-	CString m_sChatColor_8;
+	QString m_sChatColor_8;
 	/** */
-	CString m_sChatColor_9;
+	QString m_sChatColor_9;
 	/** */
-	CString m_sChatColor_10;
+	QString m_sChatColor_10;
 	/** */
-	CString m_sChatColor_11;
+	QString m_sChatColor_11;
 	/** */
-	CString m_sChatColor_12;
+	QString m_sChatColor_12;
 	/** */
-	CString m_sChatColor_13;
+	QString m_sChatColor_13;
 	/** */
-	CString m_sChatColor_14;
+	QString m_sChatColor_14;
 	/** */
-	CString m_sChatColor_15;
+	QString m_sChatColor_15;
 	/** */
-	CString m_sChatColor_16;
+	QString m_sChatColor_16;
 	/** */
-	CString m_sChatColor_17;
+	QString m_sChatColor_17;
 	/** */
-	CString m_sChatColor_18;
+	QString m_sChatColor_18;
 	/** Colour for operator nick */
-	CString m_sChatColor_19;
+	QString m_sChatColor_19;
+	/** true to use custom chat background color */
+	bool m_bChatBackgroundColorEnabled;
 	/** */
-	bool bOpenClientWindowsMinimized;
+	QString m_sChatBackgroundColor;
+	/** */
+	int m_nOpenClientWindows;
 	/** */
 	bool m_bChatShowJoinsAndParts;
 	/** */
 	bool m_bChatShowJoinsAndPartsOnlyFav;
 
-	/** The default remote text encoding for filelist browsers */
-	QString m_sDefaultFBRemoteEncoding;
-	
 	/** */
-	bool m_bClientColumnComment;
-	/** */
-	bool m_bClientColumnTag;
-	/** */
-	bool m_bClientColumnEMail;
-	/** */
-	bool m_bClientColumnSpeed;
-	/** */
-	bool m_bClientColumnShare;
-	/** */
-	bool m_bClientColumnIP;
-	/** */
-	bool m_bClientColumnLOCKPK;
-	/** */
-	bool m_bClientColumnSUPPORTS;
-
-	/** */
-	int iClientColumnNick;
-	/** */
-	int iClientColumnComment;
-	/** */
-	int iClientColumnTag;
-	/** */
-	int iClientColumnEMail;
-	/** */
-	int iClientColumnSpeed;
-	/** */
-	int iClientColumnShare;
-	/** */
-	int iClientColumnIP;
-	/** */
-	int iClientColumnLOCKPK;
-	/** */
-	int iClientColumnSUPPORTS;
-
-	/** */
-	CString m_sUserPhotoFileName;
+	QString m_sUserPhotoFileName;
 	
 	/** The list of user customized chat commands */
-	CList<DC_UserChatCommand> m_lUserChatCommands;
+	QList<DC_UserChatCommand*> m_lUserChatCommands;
 
-	/** The list of user customized menu commands */
-	CList<DC_UserMenuCommand> m_lUserMenuCommands;
+	/** The list of user customized menu commands - now in order! */
+	QMap<int, DC_UserMenuCommand*> m_UserMenuCommands;
 	
 	/** Theme for application icons */
 	QString m_sApplicationIconTheme;
@@ -863,8 +918,12 @@ private:
 	/** Regexp of nicks to not open chat windows for */
 	QString m_sSuppressedNicks;
 	
-	/** Action to do on double clicking a user */
-	QString m_sDoubleClickAction;
+	/**
+	 * Action to do on double clicking a user
+	 * 0 is private chat
+	 * 1 is download filelist
+	 */
+	int m_nDoubleClickAction;
 	
 	/** True if auto responder is enabled for main chat */
 	bool m_bAutoResponderEnabled;
@@ -873,13 +932,13 @@ private:
 	bool m_bAutoResponderEnabledForPM;
 	
 	/** The list of auto response triggers and responses */
-	CList<DC_AutoResponseObject> m_lAutoResponses;
+	QList<DC_AutoResponseObject*> m_lAutoResponses;
 	
 	/** The time between consequtive auto-responses for a user */
 	long m_nAutoResponseDelay;
 	
 	/** A list of nicks to not auto respond to */
-	CString m_sAutoResponseIgnores;
+	QString m_sAutoResponseIgnores;
 	
 	/** The filelist naming scheme version.
 	  * This is set internally so that the filelists are renamed
@@ -888,7 +947,7 @@ private:
 	int m_nFilelistNamingSchemeVersion;
 	
 	/** Saved QT4 QMainWindow state */
-	QString m_sQT4MainWindowState;
+	QByteArray m_baQMainWindowState;
 	
 	/** Show folders in right pane of filelist browser? */
 	bool m_bFoldersInRightPane;
@@ -896,6 +955,35 @@ private:
 	bool m_bFolderSizesInLeftPane;
 	/** Sort folders in right pane on top */
 	bool m_bFoldersInRightPaneOnTop;
+	/** Open folders in right pane by double clicking */
+	bool m_bOpenFoldersInRightPane;
+	/** Send unknown /commands as chat */
+	bool m_bSendUnknownCommandsAsChat;
+	/** List of allowed unknown commands */
+	QString m_sAllowedUnknownCommands;
+	/** Adjust hub details in search results */
+	bool m_bAdjustSearchResultHubNames;
+	/** True if the remove public hub item is enabled */
+	bool m_bRemovePublicHubEnabled;
+	
+	/** */
+	int m_nTabCompleteMatchMode;
+	/** */
+	bool m_bTabCompleteStripTags;
+	
+	/** use threads to start shell commands and wait for them to finish */
+	bool m_bThreadsForShellCommands;
+	/** how long to wait for shell commands to finish when not using threads */
+	int m_nShellCommandTimeout;
+	
+	/** if true, user commands start in a submenu */
+	bool m_bUserCommandSubmenu;
+	
+	/** Use alternating row colors */
+	bool m_bAlternatingRowColors;
+	
+	/** default magnet action */
+	eMagnetAction m_eMagnetActionChat;
 };
 
 /** global config */
@@ -940,49 +1028,43 @@ inline eUnit DCConfig::GetUnit() const
 inline void DCConfig::SetUnit( eUnit unit )
 { m_eUnit = unit; }
 /** */
-inline CString DCConfig::GetTheme() const
+inline QString DCConfig::GetTheme() const
 { return sTheme; }
 /** */
-inline void DCConfig::SetTheme( CString theme )
+inline void DCConfig::SetTheme( QString theme )
 { sTheme = theme; }
 
 /** */
-inline CString DCConfig::GetSendChat() const
-{ return sSendChat; }
+inline int DCConfig::GetSendChat() const
+{ return m_nSendChat; }
 /** */
-inline void DCConfig::SetSendChat( CString sendchat )
-{ sSendChat = sendchat; }
+inline void DCConfig::SetSendChat( int index )
+{ m_nSendChat = index; }
 
 /** */
-inline CString DCConfig::GetLanguageFile() const
+inline QString DCConfig::GetLanguageFile() const
 { return sLanguageFile; }
 /** */
-inline void DCConfig::SetLanguageFile( CString languagefile )
+inline void DCConfig::SetLanguageFile( QString languagefile )
 { sLanguageFile = languagefile; }
 
-inline CString DCConfig::GetAppFont() const
+inline QString DCConfig::GetAppFont() const
 { return sAppFont; }
-inline void DCConfig::SetAppFont(CString font)
+inline void DCConfig::SetAppFont(QString font)
 { sAppFont = font; }
 /** */
+inline bool DCConfig::GetUseCustomFont() const
+{ return m_bUseCustomFont; }
+/** */
+inline void DCConfig::SetUseCustomFont( bool b )
+{ m_bUseCustomFont = b; }
+/** */
 inline void DCConfig::SetAppGeometry( int width, int height )
 { iAppWidth=width;iAppHeight=height; }
 /** */
 inline void DCConfig::GetAppGeometry( int &width, int &height )
 { width=iAppWidth;height=iAppHeight; }
 /** */
-inline void DCConfig::SetTransferViewGeometry( int width, int height )
-{ iTransferViewWidth=width;iTransferViewHeight=height; }
-/** */
-inline void DCConfig::GetTransferViewGeometry( int &width, int &height )
-{ width=iTransferViewWidth;height=iTransferViewHeight; }
-/** */
-inline void DCConfig::SetTransferViewDocked( bool b )
-{ bTransferViewDocked = b; }
-/** */
-inline bool DCConfig::GetTransferViewDocked() const
-{ return bTransferViewDocked; }
-/** */
 inline bool DCConfig::GetSoundDisabled() const
 { return bSoundDisabled; }
 /** */
@@ -1001,10 +1083,10 @@ inline bool DCConfig::GetExternalSoundPlayer() const
 inline void DCConfig::SetExternalSoundPlayer( bool externalsoundplayer )
 { bExternalSoundPlayer = externalsoundplayer; }
 /** */
-inline CString DCConfig::GetExternalPlayer() const
+inline QString DCConfig::GetExternalPlayer() const
 { return sExternalPlayer; }
 /** */
-inline void DCConfig::SetExternalPlayer( CString externalplayer )
+inline void DCConfig::SetExternalPlayer( QString externalplayer )
 { sExternalPlayer = externalplayer; }
 /** */
 inline bool DCConfig::GetShowStatusMessage() const
@@ -1052,9 +1134,6 @@ inline bool DCConfig::GetFloodOpKick() const
 inline unsigned int DCConfig::GetDefaultDownloadMode() const
 { return iDefaultDownloadMode; }
 /** */
-inline void DCConfig::SetDefaultDownloadMode( unsigned int n )
-{ iDefaultDownloadMode = n; }
-/** */
 inline bool DCConfig::GetEnableEmoticons() const
 { return bEnableEmoticons; }
 /** */
@@ -1085,18 +1164,24 @@ inline bool DCConfig::GetShowChatSendButton() const
 inline void DCConfig::SetShowChatSendButton( bool b )
 { bShowChatSendButton = b; }
 /** */
-inline CString DCConfig::GetBackgroundPixmap() const
+inline QString DCConfig::GetBackgroundPixmap() const
 { return sBackgroundPixmap; }
 /** */
-inline void DCConfig::SetBackgroundPixmap( CString s )
+inline void DCConfig::SetBackgroundPixmap( QString s )
 { sBackgroundPixmap = s; }
 /** */
-inline CString DCConfig::GetBrowser() const
+inline QString DCConfig::GetBrowser() const
 { return sBrowser; }
 /** */
-inline void DCConfig::SetBrowser( CString s )
+inline void DCConfig::SetBrowser( QString s )
 { sBrowser = s; }
 /** */
+inline bool DCConfig::GetCustomBrowser() const
+{ return m_bCustomBrowser; }
+/** */
+inline void DCConfig::SetCustomBrowser( bool b )
+{ m_bCustomBrowser = b; }
+/** */
 inline bool DCConfig::GetShowChatInTab() const
 { return bShowChatInTab; }
 /** */
@@ -1109,22 +1194,19 @@ inline long DCConfig::GetChatMaxParagraph() const
 inline void DCConfig::SetChatMaxParagraph( long i )
 { m_nChatMaxParagraph = i; }
 /** */
-inline bool DCConfig::GetOpenClientWindowsMinimized() const
-{ return bOpenClientWindowsMinimized; }
+inline int DCConfig::GetOpenClientWindows() const
+{ return m_nOpenClientWindows; }
 /** */
-inline void DCConfig::SetOpenClientWindowsMinimized( bool b )
-{ bOpenClientWindowsMinimized = b; }
+inline void DCConfig::SetOpenClientWindows( int i )
+{ m_nOpenClientWindows = i; }
 /** */
 inline bool DCConfig::GetAutoAwayMode() const
 { return m_bAutoAwayMode; }
 /** */
-inline void DCConfig::SetAutoAwayMode( bool b )
-{ m_bAutoAwayMode = b; }
-/** */
-inline int DCConfig::GetAutoAwayTime() const
+inline unsigned int DCConfig::GetAutoAwayTime() const
 { return m_nAutoAwayTime; }
 /** */
-inline void DCConfig::SetAutoAwayTime( int n )
+inline void DCConfig::SetAutoAwayTime( unsigned int n )
 { m_nAutoAwayTime = n; }
 /** */
 inline bool DCConfig::GetChatShowJoinsAndParts() const
@@ -1139,18 +1221,12 @@ inline bool DCConfig::GetChatShowJoinsAndPartsOnlyFav() const
 inline void DCConfig::SetChatShowJoinsAndPartsOnlyFav( bool b )
 { m_bChatShowJoinsAndPartsOnlyFav = b; }
 /** */
-inline CString DCConfig::GetUserPhotoFileName() const
+inline QString DCConfig::GetUserPhotoFileName() const
 { return m_sUserPhotoFileName; }
 /** */
-inline void DCConfig::SetUserPhotoFileName( CString s )
+inline void DCConfig::SetUserPhotoFileName( QString s )
 { m_sUserPhotoFileName = s; }
 /** */
-inline QString DCConfig::GetDefaultFBRemoteEncoding() const
-{ return m_sDefaultFBRemoteEncoding; }
-/** */
-inline void DCConfig::SetDefaultFBRemoteEncoding( QString s )
-{ m_sDefaultFBRemoteEncoding = s; }
-/** */
 inline QString DCConfig::GetValknutDataPath() const
 { return m_sValknutDataPath; }
 /** */
@@ -1172,23 +1248,17 @@ inline void DCConfig::SetEmoticonTheme( QString s )
 inline QString DCConfig::GetUserListIconTheme() const
 { return m_sUserListIconTheme; }
 /** */
-inline void DCConfig::SetUserListIconTheme( QString s )
-{ m_sUserListIconTheme = s; }
-/** */
-inline void DCConfig::SetUserIcons( QPixmap p )
-{ m_UserIcons = p; }
-/** */
 inline QString DCConfig::GetSuppressedNicks() const
 { return m_sSuppressedNicks; }
 /** */
 inline void DCConfig::SetSuppressedNicks( QString s )
 { m_sSuppressedNicks = s; }
 /** */
-inline QString DCConfig::GetDoubleClickAction() const
-{ return m_sDoubleClickAction; }
+inline int DCConfig::GetDoubleClickAction() const
+{ return m_nDoubleClickAction; }
 /** */
-inline void DCConfig::SetDoubleClickAction( QString s )
-{ m_sDoubleClickAction = s; }
+inline void DCConfig::SetDoubleClickAction( int index )
+{ m_nDoubleClickAction = index; }
 /** */
 inline bool DCConfig::GetAutoResponderEnabled() const
 { return m_bAutoResponderEnabled; }
@@ -1202,10 +1272,10 @@ inline long DCConfig::GetAutoResponseDelay() const
 inline void DCConfig::SetAutoResponseDelay( long n )
 { m_nAutoResponseDelay = n; }
 /** */
-inline CString DCConfig::GetAutoResponseIgnores() const
+inline QString DCConfig::GetAutoResponseIgnores() const
 { return m_sAutoResponseIgnores; }
 /** */
-inline void DCConfig::SetAutoResponseIgnores( CString s )
+inline void DCConfig::SetAutoResponseIgnores( QString s )
 { m_sAutoResponseIgnores = s; }
 /** */
 inline bool DCConfig::GetAutoResponderEnabledForPM() const
@@ -1220,6 +1290,12 @@ inline int DCConfig::GetFilelistNamingSchemeVersion() const
 inline void DCConfig::SetFilelistNamingSchemeVersion( int i )
 { m_nFilelistNamingSchemeVersion = i; }
 /** */
+inline QByteArray DCConfig::GetQMainWindowState() const
+{ return m_baQMainWindowState; }
+/** */
+inline void DCConfig::SetQMainWindowState( QByteArray ba )
+{ m_baQMainWindowState = ba; }
+/** */
 inline bool DCConfig::GetFoldersInRightPane() const
 { return m_bFoldersInRightPane; }
 /** */
@@ -1237,4 +1313,73 @@ inline bool DCConfig::GetFoldersInRightPaneOnTop() const
 /** */
 inline void DCConfig::SetFoldersInRightPaneOnTop( bool b )
 { m_bFoldersInRightPaneOnTop = b; }
+/** */
+inline bool DCConfig::GetOpenFoldersInRightPane() const
+{ return m_bOpenFoldersInRightPane; }
+/** */
+inline void DCConfig::SetOpenFoldersInRightPane( bool b )
+{ m_bOpenFoldersInRightPane = b; }
+/** */
+inline bool DCConfig::GetSendUnknownCommandsAsChat() const
+{ return m_bSendUnknownCommandsAsChat; }
+/** */
+inline void DCConfig::SetSendUnknownCommandsAsChat( bool b )
+{ m_bSendUnknownCommandsAsChat = b; }
+/** */
+inline QString DCConfig::GetAllowedUnknownCommands() const
+{ return m_sAllowedUnknownCommands; }
+/** */
+inline void DCConfig::SetAllowedUnknownCommands( QString s )
+{ m_sAllowedUnknownCommands = s; }
+/** */
+inline bool DCConfig::GetAdjustSearchResultHubNames() const
+{ return m_bAdjustSearchResultHubNames; }
+/** */
+inline void DCConfig::SetAdjustSearchResultHubNames( bool b )
+{ m_bAdjustSearchResultHubNames = b; }
+/** */
+inline bool DCConfig::GetRemovePublicHubEnabled() const
+{ return m_bRemovePublicHubEnabled; }
+/** */
+inline void DCConfig::SetRemovePublicHubEnabled( bool b )
+{ m_bRemovePublicHubEnabled = b; }
+/** */
+inline int DCConfig::GetTabCompleteMatchMode() const
+{ return m_nTabCompleteMatchMode; }
+/** */
+inline void DCConfig::SetTabCompleteMatchMode( int i )
+{ m_nTabCompleteMatchMode = i; }
+/** */
+inline bool DCConfig::GetTabCompleteStripTags() const
+{ return m_bTabCompleteStripTags; }
+/** */
+inline void DCConfig::SetTabCompleteStripTags( bool b )
+{ m_bTabCompleteStripTags = b; }
+/** */
+inline bool DCConfig::GetThreadsForShellCommands() const
+{ return m_bThreadsForShellCommands; }
+/** */
+inline void DCConfig::SetThreadsForShellCommands( bool b )
+{ m_bThreadsForShellCommands = b; }
+/** */
+inline int DCConfig::GetShellCommandTimeout() const
+{ return m_nShellCommandTimeout; }
+/** */
+inline void DCConfig::SetShellCommandTimeout( int s )
+{ m_nShellCommandTimeout = s; }
+/** */
+inline bool DCConfig::GetUserCommandSubmenu() const
+{ return m_bUserCommandSubmenu; }
+/** */
+inline void DCConfig::SetUserCommandSubmenu( bool b )
+{ m_bUserCommandSubmenu = b; }
+/** */
+inline bool DCConfig::GetChatBackgroundColorEnabled() const
+{ return m_bChatBackgroundColorEnabled; }
+/** */
+inline QString DCConfig::GetChatBackgroundColor() const
+{ return m_sChatBackgroundColor; }
+/** */
+inline bool DCConfig::GetAlternatingRowColors() const
+{ return m_bAlternatingRowColors; }
 #endif
