@@ -2,7 +2,7 @@
                           dceditserver.cpp  -  description
                              -------------------
     begin                : Fre Aug 29 2003
-    copyright            : (C) 2003 by Mathias Kster
+    copyright            : (C) 2003 by Mathias Küster
     email                : mathen@users.berlios.de
  ***************************************************************************/
 
@@ -15,21 +15,35 @@
  *                                                                         *
  ***************************************************************************/
 
+#include "dceditserver.h"
+
 #include <qpushbutton.h>
-#include <qtoolbutton.h>
-#include <qgroupbox.h>
 #include <qlineedit.h>
 #include <qcheckbox.h>
-#include <qregexp.h>
+#include <qcombobox.h>
+#include <qmessagebox.h>
 
 #include <dclib/cconfig.h>
 
-#include "dceditserver.h"
+#include "dcguiutils.h"
 
 /** */
-DCEditServer::DCEditServer(QWidget *parent, const char *name ) : DCDialogEditServer(parent,name)
+DCEditServer::DCEditServer( QWidget * parent ) : QDialog( parent )
 {
-	initDocument();
+	setupUi(this);
+	
+	ComboBox_REMOTE_ENCODING->addItem(QString());
+	DCGuiUtils::AddEncodings( ComboBox_REMOTE_ENCODING );
+	ComboBox_REMOTE_ENCODING->setCurrentIndex(0);
+	
+	GroupBox_PROFILE->hide();
+	adjustSize();
+
+	connect( PushButton_PROFILE, SIGNAL(clicked()), this, SLOT(slotProfileButtonClicked()) );
+	connect( CheckBox_PROFILE, SIGNAL(toggled(bool)), this, SLOT(slotCheckBoxProfileToggled(bool)) );
+	
+	// reset values
+	Reset();
 }
 
 /** */
@@ -38,34 +52,45 @@ DCEditServer::~DCEditServer()
 }
 
 /** */
-void DCEditServer::initDocument()
+void DCEditServer::accept()
 {
-	GroupBox_PROFILE->hide();
-
-	adjustSize();
-
-	connect( PushButton_OK, SIGNAL(clicked()), this, SLOT(accept()) );
-	connect( PushButton_CANCEL, SIGNAL(clicked()), this, SLOT(reject()) );
-	connect( ToolButton_PROFILE, SIGNAL(clicked()), this, SLOT(slotToolButtonProfileClicked()) );
-
-	connect( CheckBox_PROFILE, SIGNAL(toggled(bool)), this, SLOT(slotCheckBoxProfileToggled(bool)) );
-	
-	// reset values
-	Reset();
+	if ( LineEdit_NAME->text().isEmpty() )
+	{
+		QMessageBox::critical(
+			this,
+			windowTitle(),
+			tr("Please enter a hubname.")
+		);
+		return;
+	}
+	else if ( LineEdit_HOST->text().isEmpty() )
+	{
+		QMessageBox::critical(
+			this,
+			windowTitle(),
+			tr("Please enter a hubhost.")
+		);
+		return;
+	}
+	else
+	{
+		QDialog::accept();
+	}
 }
 
 /** */
 void DCEditServer::Reset()
 {
-	LineEdit_PASSWORD->setText("");
-	CheckBox_AUTOCONNECT->setChecked(FALSE);
-	CheckBox_SSL->setChecked(FALSE);
-	CheckBox_DESCRIPTIONTAG->setChecked(TRUE);
-	CheckBox_EXT_HUB_COUNT->setChecked(TRUE);
-	LineEdit_SUPPRESS_NICKS->setText("");
+	LineEdit_PASSWORD->clear();
+	CheckBox_AUTOCONNECT->setChecked(false);
+	CheckBox_SSL->setChecked(false);
+	CheckBox_DESCRIPTIONTAG->setChecked(true);
+	CheckBox_EXT_HUB_COUNT->setChecked(true);
+	LineEdit_SUPPRESS_NICKS->clear();
+	ComboBox_REMOTE_ENCODING->setCurrentIndex(0);
 
 	// disable profile
-	slotCheckBoxProfileToggled(FALSE);
+	slotCheckBoxProfileToggled(false);
 }
 
 /** */
@@ -82,33 +107,33 @@ void DCEditServer::SetProfile( DCConfigHubProfile * profile )
 	LineEdit_PROF_DESCRIPTION->setText( profile->m_sComment.Data() );
 	CheckBox_DESCRIPTION->setChecked( profile->m_bComment );
 	LineEdit_SUPPRESS_NICKS->setText( profile->m_sSuppressedNicks.Data() );
+	ComboBox_REMOTE_ENCODING->setEditText( profile->m_sRemoteEncoding.Data() );
 
 	// enable profile
-	slotCheckBoxProfileToggled(TRUE);
+	slotCheckBoxProfileToggled(true);
 }
 
 /** */
 void DCEditServer::GetProfile( DCConfigHubProfile * profile )
 {
-	profile->m_sName        = LineEdit_NAME->text();
-	profile->m_sNick        = LineEdit_NICK->text().replace( QRegExp(" "), "\xa0").ascii();
-	profile->m_sPassword    = LineEdit_PASSWORD->text().ascii();
+	profile->m_sName        = LineEdit_NAME->text().toAscii().constData();
+	profile->m_sNick        = LineEdit_NICK->text().replace( " ", "\xa0").toAscii().constData();
+	profile->m_sPassword    = LineEdit_PASSWORD->text().toAscii().constData();
 	profile->m_bAutoConnect = CheckBox_AUTOCONNECT->isChecked();
 	profile->m_bSSL         = CheckBox_SSL->isChecked();
 	profile->m_bTag         = CheckBox_DESCRIPTIONTAG->isChecked();
 	profile->m_bExtHubCount = CheckBox_EXT_HUB_COUNT->isChecked();
 	profile->m_bComment     = CheckBox_DESCRIPTION->isChecked();
-	profile->m_sComment     = LineEdit_PROF_DESCRIPTION->text();
+	profile->m_sComment     = LineEdit_PROF_DESCRIPTION->text().toAscii().constData();
 	profile->m_bEMail       = CheckBox_EMAIL->isChecked();
-	profile->m_sEMail       = LineEdit_EMAIL->text();
-	profile->m_sSuppressedNicks = LineEdit_SUPPRESS_NICKS->text().ascii();
+	profile->m_sEMail       = LineEdit_EMAIL->text().toAscii().constData();
+	profile->m_sSuppressedNicks = LineEdit_SUPPRESS_NICKS->text().toAscii().constData();
+	profile->m_sRemoteEncoding = ComboBox_REMOTE_ENCODING->currentText().toAscii().constData();
 }
 
 /** */
-void DCEditServer::slotToolButtonProfileClicked()
+void DCEditServer::slotProfileButtonClicked()
 {
-	int w = width();
-	
 	if ( GroupBox_PROFILE->isVisible() )
 	{
 		GroupBox_PROFILE->hide();
@@ -117,10 +142,6 @@ void DCEditServer::slotToolButtonProfileClicked()
 	{
 		GroupBox_PROFILE->show();
 	}
-
-	adjustSize();
-	
-	resize( w, height() );
 }
 
 /** */
@@ -133,9 +154,10 @@ void DCEditServer::slotCheckBoxProfileToggled( bool on )
 		// hide profile window if disabled
 		if ( GroupBox_PROFILE->isVisible() )
 		{
-			slotToolButtonProfileClicked();
+			PushButton_PROFILE->setChecked(false);
+			slotProfileButtonClicked();
 		}
 	}
 
-	ToolButton_PROFILE->setEnabled(on);
+	PushButton_PROFILE->setEnabled(on);
 }
