@@ -2,7 +2,7 @@
                           dcevent.cpp  -  description
                              -------------------
     begin                : Sun Dec 15 2002
-    copyright            : (C) 2002 by Mathias Kster
+    copyright            : (C) 2002 by Mathias Küster
     email                : mathen@users.berlios.de
  ***************************************************************************/
 
@@ -15,17 +15,19 @@
  *                                                                         *
  ***************************************************************************/
 
+#include "dcevent.h"
+
 #include <dclib/dcos.h>
 #include <dclib/dcobject.h>
 #include <dclib/cdownloadmanager.h>
 
-#include <dcuserslist.h>
+#include "dcfriendobject.h"
 
-#include "dcevent.h"
+#include <QEvent>
 
 // friend event
 /** */
-DC_FriendEvent::DC_FriendEvent( Type type, DCFriendObject * friendobject ) : QEvent( type )
+DC_FriendEvent::DC_FriendEvent( DCFriendObject * friendobject ) : QEvent( EVENT_UPDATE_FRIEND )
 {
 	m_pFriendObject = new DCFriendObject();
 
@@ -45,11 +47,9 @@ DC_FriendEvent::~DC_FriendEvent()
 }
 
 /** */
-DC_DownloadManagerEvent::DC_DownloadManagerEvent( Type type, CDownloadManagerInfo * info ) : QEvent( type )
+DC_DownloadManagerEvent::DC_DownloadManagerEvent( CDownloadManagerInfo * info ) : QEvent( EVENT_UPDATE_DM_STATUSBAR )
 {
-	m_pDownloadManagerInfo = new CDownloadManagerInfo();
-
-	*m_pDownloadManagerInfo = *info;
+	m_pDownloadManagerInfo = info;
 }
 
 /** */
@@ -59,11 +59,9 @@ DC_DownloadManagerEvent::~DC_DownloadManagerEvent()
 }
 
 /** */
-DC_FileManagerEvent::DC_FileManagerEvent( Type type, CFileManagerInfo * info ) : QEvent( type )
+DC_FileManagerEvent::DC_FileManagerEvent( CFileManagerInfo * info ) : QEvent( EVENT_UPDATE_FM_STATUSBAR )
 {
-	m_pFileManagerInfo = new CFileManagerInfo();
-
-	*m_pFileManagerInfo = *info;
+	m_pFileManagerInfo = info;
 }
 
 /** */
@@ -73,11 +71,9 @@ DC_FileManagerEvent::~DC_FileManagerEvent()
 }
 
 /** */
-DC_TrafficInfoEvent::DC_TrafficInfoEvent( Type type, DCMessageTraffic * info ) : QEvent( type )
+DC_TrafficInfoEvent::DC_TrafficInfoEvent( DCMessageTraffic * info ) : QEvent( EVENT_UPDATE_TR_STATUSBAR )
 {
-	m_pTrafficInfo = new DCMessageTraffic();
-
-	*m_pTrafficInfo = *info;
+	m_pTrafficInfo = info;
 }
 
 /** */
