@@ -1,8 +1,8 @@
 /***************************************************************************
                           dcfiletool.h  -  description
                              -------------------
-    begin                : Die Mr 26 2002
-    copyright            : (C) 2002 by Mathias Kster
+    begin                : Die Mär 26 2002
+    copyright            : (C) 2002 by Mathias Küster
     email                : mathen@users.berlios.de
  ***************************************************************************/
 
@@ -19,54 +19,44 @@
 #define DCFILETOOL_H
 
 /**
-  *@author Mathias Kster
+  *@author Mathias Küster
   */
 
-#include <qwidget.h>
+#include <qstring.h>
 
 #include <dclib/dcobject.h>
 
-typedef enum eRepairType {
+enum eRepairType {
 	ertNONE=0,
 	ertBYTES,
 	ertSECTORS
-} eRepairType;
+};
 
-class CString;
+class QWidget;
 
-class DCFileTool : public QWidget {
-Q_OBJECT
+class DCFileTool {
 
 public: 
-	/** construtor */
+	/** construtor - does nothing */
 	DCFileTool();
-	/** destructor */
-	virtual ~DCFileTool();
-
-	/** reset internal values */
-	void Init();
+	/** destructor - does nothing */
+	~DCFileTool();
 
 	/** */
-	bool SelectFileSource( ulonglong size, QString & file, QString & localrootpath, QString & localpath );
+	static bool SelectFileSource( QWidget * parent, ulonglong size, QString tth, QString & file, QString & localrootpath, QString & localpath );
 	/** */
-	bool AddFileSource( CString nick, CString hubname, CString hubhost,
+	static bool AddFileSource( QWidget * parent, CString nick, CString hubname, CString hubhost,
 				CString remotename, CString localname,
 				CString localpath, CString localrootpath,
 				eltMedium medium, ulonglong size, CString tth );
 	/** */
-	bool CheckFile( CString nick, CString hubname, CString hubhost,
+	static bool CheckFile( QWidget * parent, CString nick, CString hubname, CString hubhost,
 				CString remotename, CString localname,
 				CString localpath, CString localrootpath,
 				eltMedium medium, ulonglong size,
 				CString hash,
-				bool usermulti = FALSE,
+				bool usermulti = false,
 				eRepairType repair = ertNONE );
-
-private:
-	/** */
-	int m_nLastDownloadCase;
-	/** */
-	bool m_bCaseAllFiles;
 };
 
 #endif
