@@ -2,7 +2,7 @@
                           dchublistmanager.h  -  description
                              -------------------
     begin                : Mon Oct 1 2001
-    copyright            : (C) 2001-2004 by Mathias Kster
+    copyright            : (C) 2001-2004 by Mathias Küster
     email                : mathen@users.berlios.de
  ***************************************************************************/
 
@@ -19,34 +19,44 @@
 #define DCHUBLISTMANAGER_H
 
 /**
-  *@author Mathias Kster
+  *@author Mathias Küster
   */
 
 #include <qtimer.h>
+#include <QFrame>
+#include <QList>
+#include <QMap>
+#include <QMutex>
 
-#include <DCDialogHubListManager.h>
+#include "DCDialogHubListManager.h"
 
-#include <dcconfig.h>
-
-#include <dclib/core/cbytearray.h>
-#include <dclib/core/cstringlist.h>
 #include <dclib/chublistmanager.h>
 
-class DCClient;
-class QStringList;
-class QListView;
-class QWorkspace;
-class CHttp;
+class QEvent;
+class QCloseEvent;
+class QResizeEvent;
+class QShowEvent;
+class QMdiSubWindow;
+class PublicHubsModel;
+class PublicHubsProxy;
+class QTreeWidgetItem;
+class DC_HubFilterObject;
+class CDCMessage;
 
-class DCHubListManager : public DCDialogHubListManager, public CHubListManager {
+/* filtered hub list for search dialog not yet re-written */
+#include <dclib/core/cstringlist.h>
+
+class DCHubListManager : public QWidget, private Ui::DCDialogHubListManager, public CHubListManager {
 Q_OBJECT
 
 public:
 	/** construtor */
-	DCHubListManager(QWidget* parent, const char *name, int wflags);
+	DCHubListManager( QWidget * parent = 0 );
 	/** destructor */
 	virtual ~DCHubListManager();
 
+	/** Get the MDI subwindow we are in */
+	QMdiSubWindow * GetMdiSubWindow() { return m_pContainerWindow; };
 	/** */
 	void InitDocument();
 	/** */
@@ -58,49 +68,59 @@ public:
 	/** */
 	void AddBookmark( QString hubname, QString hubhost, QString description );
 	/** */
-	void RemoveBookmark( QListViewItem * item );
+	void RemoveBookmark( QTreeWidgetItem * item );
 	/** */
 	void UpdateBookmark( QString hubname, QString hubhost, QString description );
 	/** */
-	CStringList * GetFilteredHubList();
-
-	/** overridden so that the columns are resized on show() */
-	virtual void show();
+	CStringList<CString> * GetFilteredHubList();
 
 	/** callback function */
-	virtual int DC_CallBack( CObject * );
+	virtual int DC_CallBack( CDCMessage * );
 
 protected:
-	/** resize the ListView columns */
-	void ResizeListViewColumn();
+	/** Adjust column sizes preserving user set size ratios */
+	void SizeColumnsPreservingRatios();
 
 	/** event filter */
 	virtual bool eventFilter( QObject * object, QEvent * event );
-	/** close event handler */
-	virtual void closeEvent( QCloseEvent * ) { };
 	/** resize event handler */
 	virtual void resizeEvent( QResizeEvent * );
+	/** overridden so that the column widths are initialized on first show() */
+	virtual void showEvent( QShowEvent * event );
+	/** for removing mdi sub window from mdi area */
+	virtual void closeEvent( QCloseEvent * event );
 
 private:
 	/** */
 	void SetToolBar( QFrame * frame1, QFrame * frame2, bool vis );
-	/** */
-	int selectedItems( QListView * list, QPtrList<QListViewItem> & lst );
+	/**
+	 * Update CConfig with the new sorted order of the bookmarks.
+	 */
+	void updateBookmarkOrder();
+	/**
+	 * Show the "Remove bookmarks" confirmation unless it's been disabled.
+	 * 0 = remove, 1 = cancel
+	 */
+	int queryRemoveBookmarks();
 
 	/** */
-	CThread m_HLMThread;
+	QMutex m_HLMMutex;
 	/** */
-	CStringList m_HubFilterList;
+	QMap<QString, DC_HubFilterObject*> m_HubFilterMap;
 	/** */
 	QTimer m_Timer;
 	/** */
-	ulonglong m_nHubListLength;
+	QList<CDCMessage*> * m_pMessageList;
 	/** */
-	ulonglong m_nHubListProgress;
+	QMdiSubWindow * m_pContainerWindow;
 	/** */
-	CList<CObject> * m_pMessageList;
+	PublicHubsModel * model;
 	/** */
-	QWorkspace * m_pWorkspace;
+	PublicHubsProxy * proxy;
+	/** The last width that we adjusted the size of the public hubs columns for */
+	int lastPublicHubsWidth;
+	/** The last width that we adjusted the size of the bookmark hubs columns for */
+	int lastBookmarkHubsWidth;
 
 private slots:
 	/** reload public hub list */
@@ -108,15 +128,15 @@ private slots:
 	/** update public hub list */
 	void slotUpdatePublicHubList();
 	/** */
-	void slotDoubleClicked( QListViewItem * item, const QPoint &, int );
+	void slotItemActivatedPublic( const QModelIndex & index );
 	/** */
-	void slotReturnPressed( QListViewItem * item );
+	void slotItemActivatedBookmarks( QTreeWidgetItem * item, int column );
 	/** */
 	void slotConnect();
 	/** */
-	void slotRightButtonClickedPublicList( QListViewItem *, const QPoint &, int );
+	void slotContextMenuPublicList( const QPoint & );
 	/** */
-	void slotRightButtonClickedBookmarkList( QListViewItem *, const QPoint &, int );
+	void slotContextMenuBookmarkList( const QPoint & );
 	/** current tab widget change slot */
 	void slotTabWidgetCurrentChange( QWidget * );
 	/** */
@@ -129,6 +149,22 @@ private slots:
 	void slotFilterChange( const QString & );
 	/** */
 	void timerDone();
+	/** */
+	void slotMoveBookmarkUp();
+	/** */
+	void slotMoveBookmarkDown();
+	/** */
+	void slotEnableBookmarkSorting();
+	/** */
+	void slotSaveBookmarks();
+	/** */
+	void slotAltRowColors( bool enable );
+	/** */
+	void slotAddBookmark();
+	/** */
+	void slotEditBookmark();
+	/** */
+	void slotDelBookmark();
 };
 
 /** */
