@@ -2,7 +2,7 @@
                           dchubprofile.cpp  -  description
                              -------------------
     begin                : Fre Sep 20 2002
-    copyright            : (C) 2002 by Mathias Kster
+    copyright            : (C) 2002 by Mathias Küster
     email                : mathen@users.berlios.de
  ***************************************************************************/
 
@@ -15,22 +15,26 @@
  *                                                                         *
  ***************************************************************************/
 
+#include "dchubprofile.h"
+
 #include <qpushbutton.h>
 #include <qcombobox.h>
 #include <qcheckbox.h>
-#include <qinputdialog.h>
-#include <qregexp.h>
 #include <qmessagebox.h>
+#include <qcombobox.h>
 
-#include <dcconfig.h>
-
-#include <dclib/core/cstringlist.h>
-
-#include "dchubprofile.h"
+#include "dcconfig.h"
+#include "dcguiutils.h"
 
 /** */
-DCHubProfile::DCHubProfile(QWidget *parent, const char *name ) : DCDialogHubProfile(parent,name)
+DCHubProfile::DCHubProfile( QWidget * parent ) : QDialog( parent )
 {
+	setupUi(this);
+	
+	ComboBox_REMOTE_ENCODING->addItem(QString());
+	DCGuiUtils::AddEncodings( ComboBox_REMOTE_ENCODING );
+	ComboBox_REMOTE_ENCODING->setCurrentIndex(0);
+	
 	InitDocument();
 }
 
@@ -42,27 +46,26 @@ DCHubProfile::~DCHubProfile()
 /** */
 void DCHubProfile::InitDocument()
 {
-	CStringList list;
-	DCConfigHubProfile * pConfigHubProfile = 0;
-
 	ComboBox_PROFILE->clear();
 
- 	g_pConfig->GetHubProfileList( &list );
+ 	std::list<CString> * names = g_pConfig->GetHubProfileNames();
 
-	while ( list.Next((CObject*&)pConfigHubProfile) )
+	for ( std::list<CString>::const_iterator it = names->begin(); it != names->end(); ++it )
 	{
-		if ( pConfigHubProfile->m_sName != "" )
+		if ( (*it).NotEmpty() )
 		{
-			ComboBox_PROFILE->insertItem(pConfigHubProfile->m_sName.Data());
+			ComboBox_PROFILE->addItem(QString::fromAscii((*it).Data()));
 		}
 	}
 
-	connect( PushButton_OK, SIGNAL(clicked()), this, SLOT(slotClickedOK()) );
-	connect( PushButton_CANCEL, SIGNAL(clicked()), this, SLOT(reject()) );
-	connect( ComboBox_PROFILE, SIGNAL(activated( const QString & )), this, SLOT(slotProfileActiveted( const QString & )) );
+	delete names;
+
+	connect( DialogButtonBox, SIGNAL(accepted()), this, SLOT(slotClickedOK()) );
+	connect( DialogButtonBox, SIGNAL(rejected()), this, SLOT(reject()) );
+	connect( ComboBox_PROFILE, SIGNAL(currentIndexChanged( const QString & )), this, SLOT(slotProfileActiveted( const QString & )) );
 	connect( PushButton_DELETE, SIGNAL(clicked()), this, SLOT(slotProfileDelete()) );
 
-	slotProfileActiveted("");
+	slotProfileActiveted(QString());
 }
 
 /** */
@@ -70,20 +73,21 @@ void DCHubProfile::SaveProfile( QString profilename )
 {
 	DCConfigHubProfile pConfigHubProfile;
 
-	if ( profilename != "" )
+	if ( !profilename.isEmpty() )
 	{
-		pConfigHubProfile.m_sName        = profilename.ascii();
-		pConfigHubProfile.m_sNick        = LineEdit_NICK->text().replace( QRegExp(" "), "\xa0").ascii();
-		pConfigHubProfile.m_sPassword    = LineEdit_PASSWORD->text().ascii();
+		pConfigHubProfile.m_sName        = profilename.toAscii().constData();
+		pConfigHubProfile.m_sNick        = LineEdit_NICK->text().replace( " ", "\xa0").toAscii().constData();
+		pConfigHubProfile.m_sPassword    = LineEdit_PASSWORD->text().toAscii().constData();
 		pConfigHubProfile.m_bAutoConnect = CheckBox_AUTOCONNECT->isChecked();
 		pConfigHubProfile.m_bTag         = CheckBox_DESCRIPTIONTAG->isChecked();
 		pConfigHubProfile.m_bExtHubCount = CheckBox_EXT_HUB_COUNT->isChecked();
-		pConfigHubProfile.m_sComment     = LineEdit_PROF_DESCRIPTION->text().ascii();
+		pConfigHubProfile.m_sComment     = LineEdit_PROF_DESCRIPTION->text().toAscii().constData();
 		pConfigHubProfile.m_bComment     = CheckBox_DESCRIPTION->isChecked();
-		pConfigHubProfile.m_sEMail       = LineEdit_EMAIL->text().ascii();
+		pConfigHubProfile.m_sEMail       = LineEdit_EMAIL->text().toAscii().constData();
 		pConfigHubProfile.m_bEMail       = CheckBox_EMAIL->isChecked();
 		pConfigHubProfile.m_bSSL         = CheckBox_SSL->isChecked();
-		pConfigHubProfile.m_sSuppressedNicks = LineEdit_SUPPRESS_NICKS->text().ascii();
+		pConfigHubProfile.m_sSuppressedNicks = LineEdit_SUPPRESS_NICKS->text().toAscii().constData();
+		pConfigHubProfile.m_sRemoteEncoding = ComboBox_REMOTE_ENCODING->currentText().toAscii().constData();
 		
 		g_pConfig->AddHubProfile( &pConfigHubProfile );
 	}
@@ -105,30 +109,42 @@ void DCHubProfile::slotProfileActiveted( const QString & /*s*/ )
 	DCConfigHubProfile pConfigHubProfile;
 
 	// save old profile
-	if ( m_sOldName != "" )
+	if ( !m_sOldName.isEmpty() )
 	{
 		// check for changes
-		if ( g_pConfig->GetHubProfile( m_sOldName.ascii(), &pConfigHubProfile ) == TRUE )
+		if ( g_pConfig->GetHubProfile( m_sOldName.toAscii().constData(), &pConfigHubProfile ) )
 		{
-			if ( (pConfigHubProfile.m_sNick != LineEdit_NICK->text().replace( QRegExp(" "), "\xa0").ascii()) ||
-			     (pConfigHubProfile.m_sPassword != LineEdit_PASSWORD->text().ascii()) ||
+			if ( (pConfigHubProfile.m_sNick != LineEdit_NICK->text().replace( " ", "\xa0").toAscii().constData()) ||
+			     (pConfigHubProfile.m_sPassword != LineEdit_PASSWORD->text().toAscii().constData()) ||
 			     (pConfigHubProfile.m_bAutoConnect != CheckBox_AUTOCONNECT->isChecked()) ||
 			     (pConfigHubProfile.m_bTag != CheckBox_DESCRIPTIONTAG->isChecked()) ||
 			     (pConfigHubProfile.m_bExtHubCount != CheckBox_EXT_HUB_COUNT->isChecked()) ||
-			     (pConfigHubProfile.m_sEMail != LineEdit_EMAIL->text().ascii()) ||
-			     (pConfigHubProfile.m_sComment != LineEdit_PROF_DESCRIPTION->text().ascii()) ||
+			     (pConfigHubProfile.m_sEMail != LineEdit_EMAIL->text().toAscii().constData()) ||
+			     (pConfigHubProfile.m_sComment != LineEdit_PROF_DESCRIPTION->text().toAscii().constData()) ||
 			     (pConfigHubProfile.m_bComment != CheckBox_DESCRIPTION->isChecked()) ||
 			     (pConfigHubProfile.m_bEMail != CheckBox_EMAIL->isChecked()) ||
 			     (pConfigHubProfile.m_bSSL   != CheckBox_SSL->isChecked()) ||
-			     (pConfigHubProfile.m_sSuppressedNicks != LineEdit_SUPPRESS_NICKS->text().ascii()) )
+			     (pConfigHubProfile.m_sSuppressedNicks != LineEdit_SUPPRESS_NICKS->text().toAscii().constData()) ||
+			     (pConfigHubProfile.m_sRemoteEncoding != ComboBox_REMOTE_ENCODING->currentText().toAscii().constData()) )
 			{
 				// ask user to save changes
 				switch( QMessageBox::warning( this, tr("Save profile"),
 	        			tr("Do you want to save your changes?"),
-	        			tr("Save"),
-        				tr("Cancel"), 0, 0, 1 ) )
+	        			QMessageBox::Save | QMessageBox::Discard | QMessageBox::Cancel,
+        				QMessageBox::Cancel) )
 				{
-			    		case 1: // The user clicked the Quit or pressed Escape
+					case QMessageBox::Cancel:
+					{
+						int index = ComboBox_PROFILE->findText(m_sOldName);
+						if ( index != -1 )
+						{
+							disconnect( ComboBox_PROFILE, SIGNAL(currentIndexChanged( const QString & )), this, SLOT(slotProfileActiveted( const QString & )) );
+							ComboBox_PROFILE->setCurrentIndex(index);
+							connect( ComboBox_PROFILE, SIGNAL(currentIndexChanged( const QString & )), this, SLOT(slotProfileActiveted( const QString & )) );
+						}
+						return;
+					}
+			    		case QMessageBox::Discard: // The user clicked Discard
         					break;
 					default:
 						SaveProfile(m_sOldName);
@@ -142,18 +158,19 @@ void DCHubProfile::slotProfileActiveted( const QString & /*s*/ )
 	m_sOldName = ComboBox_PROFILE->currentText();
 
 	// reset values
-	LineEdit_NICK->setText("");
-	LineEdit_PASSWORD->setText("");
-	CheckBox_AUTOCONNECT->setChecked(FALSE);
-	CheckBox_DESCRIPTIONTAG->setChecked(FALSE);
-	CheckBox_EXT_HUB_COUNT->setChecked(FALSE);
-	LineEdit_EMAIL->setText("");
-	LineEdit_PROF_DESCRIPTION->setText("");
-	LineEdit_SUPPRESS_NICKS->setText("Hub");
+	LineEdit_NICK->clear();
+	LineEdit_PASSWORD->clear();
+	CheckBox_AUTOCONNECT->setChecked(false);
+	CheckBox_DESCRIPTIONTAG->setChecked(false);
+	CheckBox_EXT_HUB_COUNT->setChecked(false);
+	LineEdit_EMAIL->clear();
+	LineEdit_PROF_DESCRIPTION->clear();
+	LineEdit_SUPPRESS_NICKS->clear();
+	ComboBox_REMOTE_ENCODING->setCurrentIndex(0);
 	
-	if ( m_sOldName != "" )
+	if ( !m_sOldName.isEmpty() )
 	{
-		if ( g_pConfig->GetHubProfile( m_sOldName.ascii(), &pConfigHubProfile ) == TRUE )
+		if ( g_pConfig->GetHubProfile( m_sOldName.toAscii().constData(), &pConfigHubProfile ) )
 		{
 			LineEdit_NICK->setText( pConfigHubProfile.m_sNick.Data() );
 			LineEdit_PASSWORD->setText( pConfigHubProfile.m_sPassword.Data() );
@@ -166,6 +183,7 @@ void DCHubProfile::slotProfileActiveted( const QString & /*s*/ )
 			CheckBox_DESCRIPTION->setChecked( pConfigHubProfile.m_bComment );
 			CheckBox_SSL->setChecked(pConfigHubProfile.m_bSSL);
 			LineEdit_SUPPRESS_NICKS->setText( pConfigHubProfile.m_sSuppressedNicks.Data() );
+			ComboBox_REMOTE_ENCODING->setEditText( pConfigHubProfile.m_sRemoteEncoding.Data() );
 		}
 	}
 }
@@ -173,25 +191,22 @@ void DCHubProfile::slotProfileActiveted( const QString & /*s*/ )
 /** Deletes the selected profile, asking for confirmation */
 void DCHubProfile::slotProfileDelete()
 {
-	// return value for confirmation dialog
-	int ret = 0;
-	
 	// get currently selected profile name
-	CString profname = ComboBox_PROFILE->currentText().ascii();
+	CString profname = ComboBox_PROFILE->currentText().toAscii().constData();
 	
 	// ask for confirmation
-	ret = QMessageBox::question(this,
-				    "Are you sure?",
-				    QString("Delete profile for ") + profname.Data(),
-				    QMessageBox::Yes,
+	int ret = QMessageBox::question(this,
+				    tr("Are you sure?"),
+				    tr("Delete profile for ") + QString(profname.Data()),
+				    QMessageBox::Yes | QMessageBox::No,
 				    QMessageBox::No
 				    );
 	
 	if (ret == QMessageBox::Yes)
 	{
 		// remove profile from list
-		ComboBox_PROFILE->removeItem( ComboBox_PROFILE->currentItem() );
-		this->slotProfileActiveted("");
+		ComboBox_PROFILE->removeItem( ComboBox_PROFILE->currentIndex() );
+		slotProfileActiveted(QString());
 		
 		// delete profile
 		g_pConfig->DelHubProfile(profname);
