@@ -2,7 +2,7 @@
                           dchubprofile.h  -  description
                              -------------------
     begin                : Fre Sep 20 2002
-    copyright            : (C) 2002 by Mathias Kster
+    copyright            : (C) 2002 by Mathias Küster
     email                : mathen@users.berlios.de
  ***************************************************************************/
 
@@ -19,18 +19,18 @@
 #define DCHUBPROFILE_H
 
 #include <qwidget.h>
-#include <DCDialogHubProfile.h>
+#include "DCDialogHubProfile.h"
 
 /**
-  *@author Mathias Kster
+  *@author Mathias Küster
   */
 
-class DCHubProfile : public DCDialogHubProfile  {
+class DCHubProfile : public QDialog, private Ui::DCDialogHubProfile  {
 Q_OBJECT
 
 public: 
 	/** construtor */
-	DCHubProfile(QWidget *parent=0, const char *name=0);
+	DCHubProfile( QWidget * parent = 0 );
 	/** destructor */
 	virtual ~DCHubProfile();
 
