@@ -2,7 +2,7 @@
                           dcsplash.cpp  -  description
                              -------------------
     begin                : Fre Apr 12 2002
-    copyright            : (C) 2002 by Mathias Kster
+    copyright            : (C) 2002 by Mathias Küster
     email                : mathen@users.berlios.de
  ***************************************************************************/
 
@@ -15,40 +15,32 @@
  *                                                                         *
  ***************************************************************************/
 
+#include "dcsplash.h"
+
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
-#include <qtranslator.h>
 #include <qlabel.h>
 #include <qpixmap.h>
 
-#include <dciconloader.h>
-
-#include "dcsplash.h"
-
-#include <dclib/dcos.h>
-
-#if QT_VERSION >= 0x030200
-#define WSTYLE_SPLASH	Qt::WStyle_Splash
-#else
-#define WSTYLE_SPLASH	WStyle_NoBorder | WStyle_StaysOnTop | WStyle_Tool | WWinOwnDC | WX11BypassWM
-#endif
+#include "dciconloader.h"
 
 /** */
-DCSplash::DCSplash(QWidget *parent, const char *name, int /*wflags*/ ) : DCDialogSplash(parent,name,WSTYLE_SPLASH)
+DCSplash::DCSplash( QWidget * parent ) : QWidget( parent )
 {
-	QPixmap pm(g_pIconLoader->GetPixmap(eiSPLASH));
-
-	Frame_PIXMAP->setBackgroundPixmap(pm);
-
-	Frame_PIXMAP->setText( tr("Valknut " VERSION
-				"\n\nOriginal Author: Mathias Kster"
-				"\nCurrent Maintainer: Edward Sheldrake"
-				"\nLogo: Mathias Kster"
-				"\n\nhttp://wxdcgui.sourceforge.net"));
-
-	Frame_PIXMAP->installEventFilter(this);
+	setupUi(this);
+	
+	setWindowFlags(Qt::SplashScreen);
+	
+	QPalette palette = Frame_PIXMAP->palette();
+	palette.setBrush( Frame_PIXMAP->backgroundRole(), QBrush(g_pIconLoader->GetPixmap(eiSPLASH)) );
+	palette.setColor( Frame_PIXMAP->foregroundRole(), QColor(255, 255, 255) );
+	
+	Frame_PIXMAP->setPalette(palette);
+	
+	// no tr() since translator hasn't been loaded yet
+	Frame_PIXMAP->setText( QString::fromAscii("Valknut ") + QString::fromAscii(PACKAGE_VERSION) + QString::fromAscii("\n\n\nhttp://wxdcgui.sourceforge.net") );
 }
 
 /** */
@@ -56,15 +48,27 @@ DCSplash::~DCSplash()
 {
 }
 
-/** event filter */
-bool DCSplash::eventFilter(QObject* object, QEvent* event)
+/** */
+void DCSplash::mouseDoubleClickEvent( QMouseEvent * event )
 {
-	if ( (event->type() == QEvent::MouseButtonPress) ||
-	     (event->type() == QEvent::MouseButtonRelease) ||
-	     (event->type() == QEvent::MouseButtonDblClick) )
-	{
-		hide();
-	}
+	hide();
 
-	return QWidget::eventFilter( object, event );    // standard event processing
+	QWidget::mouseDoubleClickEvent( event );    // standard event processing
 }
+
+/** */
+void DCSplash::mousePressEvent( QMouseEvent * event )
+{
+	hide();
+
+	QWidget::mousePressEvent( event );    // standard event processing
+}
+
+/** */
+void DCSplash::mouseReleaseEvent( QMouseEvent * event )
+{
+	hide();
+
+	QWidget::mouseReleaseEvent( event );    // standard event processing
+}
+
