@@ -2,7 +2,7 @@
                           dcsplash.h  -  description
                              -------------------
     begin                : Fre Apr 12 2002
-    copyright            : (C) 2002 by Mathias Kster
+    copyright            : (C) 2002 by Mathias Küster
     email                : mathen@users.berlios.de
  ***************************************************************************/
 
@@ -19,24 +19,30 @@
 #define DCSPLASH_H
 
 /**
-  *@author Mathias Kster
+  *@author Mathias Küster
   */
 
 #include <qwidget.h>
-#include <DCDialogSplash.h>
+#include <qevent.h>
 
-class DCSplash : public DCDialogSplash  {
+#include "DCDialogSplash.h"
+
+class DCSplash : public QWidget, public Ui::DCDialogSplash  {
 Q_OBJECT
 
 public: 
 	/** construtor */
-	DCSplash(QWidget *parent=0, const char *name=0, int wflags=0);
+	DCSplash( QWidget * parent = 0 );
 	/** destructor */
 	virtual ~DCSplash();
 
 protected:
-	/** event filter */
-	virtual bool eventFilter(QObject* object, QEvent* event);
+	/** */
+	virtual void mouseDoubleClickEvent( QMouseEvent * event );
+	/** */
+	virtual void mousePressEvent( QMouseEvent * event );
+	/** */
+	virtual void mouseReleaseEvent( QMouseEvent * event );
 };
 
 #endif
