@@ -2,7 +2,7 @@
                           dcspy.h  -  description
                              -------------------
     begin                : Fre Nov 8 2002
-    copyright            : (C) 2002 by Mathias Kster
+    copyright            : (C) 2002 by Mathias Küster
     email                : mathen@users.berlios.de
  ***************************************************************************/
 
@@ -21,46 +21,55 @@
 #include <qwidget.h>
 #include <qtimer.h>
 
-#include <DCDialogSpy.h>
+#include "DCDialogSpy.h"
 
-#include <dclib/dcobject.h>
+class QMdiSubWindow;
+class SearchSpyModel;
+class CMessageSearchFile;
+class QCloseEvent;
 
 /**
-  *@author Mathias Kster
+  *@author Mathias Küster
   */
 
-class DCSpy : public DCDialogSpy  {
+class DCSpy : public QWidget, private Ui::DCDialogSpy  {
 Q_OBJECT
 
 public: 
 	/** construtor */
-	DCSpy(QWidget *parent, const char *name, int wflags);
+	DCSpy( QWidget * parent );
 	/** destructor */
 	virtual ~DCSpy();
 	
+	/** Get the MDI sub window we are in */
+	QMdiSubWindow * GetMdiSubWindow() { return m_pContainerWindow; } ;
 	/** */
 	void InitDocument();
 	/** */
 	void DeInitDocument();
 
 	/** search */
-	void DC_Search( CMessageSearch * MessageSearch );
+	void DC_Search( CMessageSearchFile * MessageSearch );
 
 protected:
-	/** close event handler */
-	virtual void closeEvent(QCloseEvent*) {};
+	/** for removing mdi sub window from mdi area */
+	virtual void closeEvent( QCloseEvent * e );
 
 private:
 	/** */
 	QTimer m_Timer;
+	/** */
+	QMdiSubWindow * m_pContainerWindow;
+	/** */
+	SearchSpyModel * model;
 	
 private slots:
-	/** */
-	void slotClickedClear();
 	/** */
 	void timerDone();
 	/** */
-	void slotContextMenuSpy( QListViewItem*, const QPoint &, int );
+	void slotContextMenuSpy( const QPoint & );
+	/** */
+	void slotAltRowColors( bool enable );
 };
 
 /** */
