@@ -2,7 +2,7 @@
                           dcuserslist.h  -  description
                              -------------------
     begin                : Thu Nov 21 2002
-    copyright            : (C) 2002 by Franois Gannaz
+    copyright            : (C) 2002 by François Gannaz
  ***************************************************************************/
 
 /***************************************************************************
@@ -18,67 +18,36 @@
 #define DCUSERSLIST_H
 
 /**
-  *@author Franois Gannaz
+  *@author François Gannaz
   */
 
-#include <dclib/core/cstring.h>
-#include <dclib/core/cstringlist.h>
 #include <dclib/dcobject.h>
 
-#include <DCDialogUsersList.h>
+#include "DCDialogUsersList.h"
+#include <QMap>
+#include <QString>
 
-class QWorkspace;
-class QListViewItem;
-class QStatusBar;
+class QMdiSubWindow;
+class QEvent;
+class QCloseEvent;
+class QResizeEvent;
+class QShowEvent;
 class CByteArray;
 
-class DCFriendObject : public CObject {
-public:
-	/** construtor */
-	DCFriendObject() {
-		m_pItem      = 0;
-		m_eAwayMode  = euamOFFLINE;
-		m_bAutoSec   = FALSE;
-		m_bSendImage = FALSE;
-		m_bPermSlot  = FALSE;
-		m_bIgnore    = FALSE;
-	};
-	/** destructor */
-	virtual ~DCFriendObject() {};
+// stupid typedef vs forward declaration
+#include "dcfriendobject.h"
 
-	QListViewItem * m_pItem;
-
-	/** */
-	CString m_sName;
-	/** */
-	CString m_sDescription;
-	/** */
-	CString m_sHubName;
-	/** */
-	CString m_sHubHost;
-	/** */
-	eUserAwayMode m_eAwayMode;
-	/** */
-	bool m_bAutoSec;
-	/** */
-	CString m_sImageFileName;
-	/** */
-	bool m_bSendImage;
-	/** If true, grant this user a permanent slot */
-	bool m_bPermSlot;
-	/** If true, ignore main chat lines from this user */
-	bool m_bIgnore;
-};
-
-class DCUsersList : public DCDialogUsersList {
+class DCUsersList : public QWidget, private Ui::DCDialogUsersList {
 Q_OBJECT
 
 public:
 	/** construtor */
-	DCUsersList(QWidget* parent, const char *name, int wflags);
+	DCUsersList( QWidget * parent = 0 );
 	/** destructor */
 	virtual ~DCUsersList();
 
+	/** Get the MDI sub window we are in */
+	QMdiSubWindow * GetMdiSubWindow() { return m_pContainerWindow; } ;
 	/** */
 	void InitDocument();
 	/** */
@@ -88,46 +57,46 @@ public:
 	void ShowFriendsList();
 
 	/** */
-	void AddFriend( CString name, CString hubname, CString hubhost, CString description );
+	void AddFriend( QString name, QString hubname, QString hubhost, QString description );
 	/** */
-	void DelFriend( CString name );
+	void DelFriend( QString name );
 	/** */
-	void UpdateFriend( CString name, CString host, CString description );
+	void UpdateFriend( QString name, QString host, QString description );
 	/** */
-	bool AddFriendPhoto( CString name, CByteArray * data );
+	bool AddFriendPhoto( QString name, CByteArray * data );
 	/** Returns true if the nick is in the friend list */
-	bool isNickInList( CString name );
+	bool isNickInList( QString name );
 	/** Returns true if the nick is on ignore */
-	bool ignoreNick( CString nick );
+	bool ignoreNick( QString nick );
 	/** Sets the ignore status of a nick */
-	void setIgnore( CString nick, bool b );
-	
-	/** overridden so that the columns are resized on show() */
-	virtual void show();
+	void setIgnore( QString nick, bool b );
 
 protected:
-	/** */
-	QWorkspace *pWorkspace;
-	/** close event handler */
-	virtual void closeEvent(QCloseEvent*) {};
-	/** event filter */
-	virtual bool eventFilter( QObject * object, QEvent * event );
 	/** resize event handler */
 	virtual void resizeEvent( QResizeEvent * );
+	/** overridden so that the column widths are initialized on first show() */
+	virtual void showEvent( QShowEvent * event );
+	/** friend event handler */
+	virtual void customEvent( QEvent * event );
+	/** for removing mdi sub window from mdi area */
+	virtual void closeEvent( QCloseEvent * event );
+
 private:
+	/** The window containing us, created by the QMdiArea */
+	QMdiSubWindow * m_pContainerWindow;
 	/** */
-	CStringList * m_pFriendList;
-	/** */
-	QStatusBar * m_pStatusBar;
+	FriendMap m_FriendMap;
 
 	/** */
 	void SetAwayMode( DCFriendObject * obj, eUserAwayMode e );
-	/** */
-	int selectedItems( QListView * list, QPtrList<QListViewItem> & lst );
+	/** Adjust column sizes preserving user set size ratios */
+	void SizeColumnsPreservingRatios();
+	/** Last width the friends list was adjusted for */
+	int lastFriendsWidth;
 
 private slots:
 	/** */
-	void slotRightButtonClickedFriendList(QListViewItem*, const QPoint &, int );
+	void slotRightButtonClickedFriendList( const QPoint & );
 };
 
 /** */
